Margaret Thatcher feared GCSEs would lower school standards - Telegraph
Description: Files released by the National Archives show the then prime minister believed exam results would be distorted by &ldquo;biased&rdquo; teachers helping teenagers with coursework
Keywords: margaret thatcher, national archives, declassified papers, 1985, 1986, gcses, michael gove, keith joseph, Margaret Thatcher,Politics,News

Accessibility links

- Skip to article
- Skip to navigation

Advertisement
Telegraph.co.uk
Search - enhanced by OpenText

Saturday 03 January 2015

- Home
- Video
- News
- World
- Sport
- Finance
- Comment
- Culture
- Travel
- Life
- Women
- Fashion
- Luxury
- Tech
- Cars

- Politics
- Investigations
- Obits
- Education
- Science
- Earth
- Health
- Defence
- Scotland
- Royal
- Celebrities
- Weird

- Conservatives
- Liberal Democrats
- Labour
- Political Parties
- Scottish Politics
- Local Elections
- General election 2015

1. Home»
2. News»
3. Politics»
4. Margaret Thatcher

# Margaret Thatcher feared GCSEs would lower school standards

## Files released by the National Archives show the then prime minister believed exam results would be distorted by “biased” teachers helping teenagers with coursework

The papers reveal Margaret Thatcher did not “like the sound of the new exam” Photo: Getty Images

By Edward Malnick

11:59PM GMT 29 Dec 2014

Follow

Margaret Thatcher attempted to put off the introduction of GCSEs because she feared the exams would lead to lower standards and a “can’t fail” mentality among pupils, newly released files show.

In comments which are likely to be seen by Conservatives as a further vindication of their sweeping reforms of the exams, the then prime minister said the system would allow results to be distorted by “biased” teachers helping teenagers with coursework.

Previously unseen papers show Mrs Thatcher warned six months before GCSEs replaced O-levels in 1986 that she did not “like the sound of the new exam”, and asked for its introduction to be delayed.

However she eventually concluded that to intervene would amount to a public “contradiction” of Sir Keith Joseph, the education secretary and a close friend, and appear as if she was taking the side of teaching unions, which wanted more time to prepare for the new system. She therefore had “no option but to go ahead”, she told aides.

Her previously unknown concerns are revealed in official papers from 1986 released by the National Archive in Kew, west London.

## Related Articles

- Margaret Thatcher conducted covert war against BBC

  30 Dec 2014

- Top KGB defector begged Margaret Thatcher to secure release of his family

  30 Dec 2014

- Margaret Thatcher warned officials not to be too harsh on Belgrano whistleblower

  30 Dec 2014

- Thatcher government considered building chemical weapons stockpile

  30 Dec 2014

Her fears appear to chime with the views of Conservatives about the GCSE system today - almost 30 years later.

Michael Gove, who was education secretary until the summer, is said to believe that the introduction of the exam was a “historic mistake” that has led to a dramatic fall in standards. Before stepping aside to become Chief Whip he set in train an overhaul of the curriculum which he said would address “the pernicious damage caused by grade inflation and dumbing down”.

GCSEs were eventually introduced in September 1986 with Kenneth Baker, now Lord Baker of Dorking, as education secretary, after Sir Keith stepped down in May - weeks after his clash with Mrs Thatcher over the exams.

Sir Keith had insisted that the new scheme was intended to better stretch teenagers, creating a tougher, “clearer and fairer” system. Under the old system, as part of which more academic teenagers took O-levels and others took CSEs, individual grades were awarded largely based on the relative performance of competing candidates.

GCSEs were intended to ensure a focus on “how much or how little pupils understand, know and can do”.

Files reveal Thatcher warned against introducing 'poll tax'

Mrs Thatcher, herself a former education secretary, raised her concerns about GCSEs with Mr Joseph in the spring of 1986. However on March 6 Mr Joseph wrote to her insisting she was “misleading herself” about the exams.

He insisted that the new system would “inject more rigour” and “use-able learning” and would be “a key instrument for improving standards”.

Mrs Thatcher marked his three-page briefing note with a series of hand-written annotations, complaining about his use of “an awful lot of high language” and questioning a number of his claims.

Sir Keith said that under the O-level and CSE system pupils were “simply ranked in merit order, with little regard to how much or how little pupils understand, know and can do”.

But in a hand-written annotation to his letter Mrs Thatcher said: “This is not a correct judgement of the present examinations system. We were taught to think and apply 50 years ago.”

Mrs Thatcher was advised by the No 10 policy unit to postpone the new system until it was clear that it was “workable”. In one briefing note she was warned that “GCSE is an exam nobody will fail” and “does little for the lowest 30 per cent of students”. Implementing the new system in September was a “hopelessly unrealistic” prospect, an official said.

In a summary of Mrs Thatcher’s concerns, dated March 18 1986, Mark Addison, then her private secretary for home affairs, said the prime minister believed the new approach would lead to “lower standards; a shift away from the traditional approach to learning in favour of a ‘can’t fail’ mentality; assessment by the pupils’ own teachers with the consequent risk of introducing more bias.”

Mrs Thatcher had not, Mr Addison added, been impressed “by the jargon-soaked justifications” of the exam produced by Mr Joseph’s department.

She asked for implementation of the exam to be postponed for at least a year, in line with the demands of many teachers, to help ensure the syllabuses were “sufficiently rigorous” and the coursework “properly assessed”.

However in early April she acquiesced with Mr Joseph’s insistence that the Government should hold its course, agreeing with Tim Flesher, another of her private secretaries, that to back down would “look like taking the side of the unions”. “I agree - no option but to go ahead,” she said.

Asked about the disclosures, Lord Baker told the Telegraph: "She was concerned ... because she always felt that whenever you change anything in education it might be for the worse."

However, he added: "In defence of Keith I don't think she fully appreciated that the great thing about GCSEs is it did away with CSE, which was virtually valueless."

The standard of GCSEs was initially "high", Lord Baker added, saying there had been a "degeneration" in grades over time.

## Margaret Thatcher

- ### News »

- ### UK News »

- ### Education News »

- ### Edward Malnick »

In Margaret Thatcher

### James Kirkup's analysis

### Michael Deacon's sketch

### Buy Margaret Thatcher: The Authorized Biography by Charles Moore

### Thatcher biography: the early years

### Margaret Thatcher 1925-2013: tributes and news ebook

Top news galleries

### The search for AirAsia QZ8501

In pics: Wreckage and bodies from the missing AirAsia flight have been found.

### The 49 best British films of all time

Film

From Skyfall to Zulu, critic Barry Norman's choice of the 49 best British films of all time

Comments

### Hyper-realistic celebrity dolls

A portrait artist transforms off-the-shelf dolls into hyper-realistic models of celebrities

### The week in pictures

A round-up of our favourite photographs of the week

### Animal photos of the week

All creatures great and small in our ever popular animal gallery.

### New Year's Day swimmers

Swimmers plunge into the sea around the world on New Year's Day

### Pictures of the day

A thoughtful seal, a diving Super Woman and Kim Jong-un visits orphanage

### Celebrities and their winter coats

When fashion and practicality collide in an eruption of layers and nobody judges you for wearing the same outfit 98 times in a row

### On the road with Froome

Cyclist Chris Froome shares his Instagram moments with the Telegraph Magazine

### Culture stars who died in 2014

Culture News

We celebrate and remember the stars who passed away last year

Comments

### The 35 best TV shows on Netflix

TV

The top TV series and boxed sets

Comments

### Thousands party around Britain on NYE

A night when revellers party a little too hard

### New Year 2015 around world

In pics: Fireworks welcome in the New Year around the world.

### 30 great New Year quotes

Culture news

30 great quotes about New Year's resolutions and celebrations

Comments

### Pictures of the day

A running hare, New Year around the world and Bath bathers

Advertisement
Advertisement

### The must have political cheat sheet for everyone who is anyone in Westminster

### Read our latest comment and analysis

More from the web

Advertisement

More from the web

News Most Viewed

- TODAY
- PAST WEEK
- PAST MONTH

1. Couple stranded in New York with newborn baby freed from £130,000 medical bill
2. Holiday windfall for Britons as euro slides
3. Meet the Arab Christians who want to fight for Israel
4. Gales and snow to divide the country
5. Has Stanford University found a cure for Alzheimer's disease?

1. AirAsia: search resumes for remaining bodies
2. Top Gear: What really happened in Patagonia?
3. 'Young people lost generation who can't fix gadgets'
4. How to see Santa (aka the ISS) flying by on Christmas Eve
5. The baby from Teletubbies reveals herself

1. AirAsia: search resumes for remaining bodies
2. Gunman and two hostages killed in bloody end to Sydney siege
3. Top Gear: What really happened in Patagonia?
4. 'Young people lost generation who can't fix gadgets'
5. World's fattest man Keith Martin dies, aged 44

Advertisement

More from the web

MORE FROM TELEGRAPH.CO.UK

US News

### Latest and breaking stories from the United States

View
Football

### Catch up on all the latest football news

View
Audi

### Audi R18 in pictures

View
Goodwood

### The very best of Goodwood's Moving Motor Show in pictures

View

Back to top

- HOME
- News
- UK News
- Politics

- Long Reads

- Wikileaks
- Jobs

- World News
- Europe
- USA
- China

- Royal Family News

- Celebrity news
- Dating

- Finance
- Education
- Defence
- Health

- Weird News

- Editor's Choice
- Financial Services

- Pictures
- Video
- Matt
- Alex

- Comment

- Blogs
- Crossword

- Contact Us
- Privacy and Cookies
- Advertising
- Fantasy Football

- Tickets

- Announcements
- Reader Prints

- Follow Us
- Apps
- Epaper
- Expat

- Promotions
- Subscriber
- Syndication

© Copyright of Telegraph Media Group Limited 2015

Terms and Conditions

Today's News

Archive

Style Book

Weather Forecast